// -*- C++ -*-
/*!
 * @file EchoMonitor.h
 * @brief EchoMonitor component.
 * @date
 * @author Kazuo Nakayoshi <kazuo.nakayoshi@kek.jp>
 *
 * Copyright (C) 2008
 *     Kazuo Nakayoshi
 *     Electronics System Group,
 *     KEK, Japan.
 *     All rights reserved.
 *
 */

#ifndef ECHOMONITOR_H
#define ECHOMONITOR_H

#include <rtm/Manager.h>
#include <rtm/DataFlowComponentBase.h>
#include <rtm/CorbaPort.h>
#include <rtm/DataInPort.h>
#include <rtm/DataOutPort.h>
#include <rtm/idl/BasicDataTypeSkel.h>
#include "MlfComponent.h"
#include "MyRingBuffer.h"
#include "ConditionEchoMonitor.h"

////////// ROOT Include files //////////
#include "TH1.h"
#include "TCanvas.h"
#include "TApplication.h"

// Service implementation headers
#include "DAQServiceSVC_impl.h"

using namespace RTC;

class EchoMonitor
    : public DAQMW::MlfComponent
{
public:
    EchoMonitor(RTC::Manager* manager);
    ~EchoMonitor();

    // The initialize action (on CREATED->ALIVE transition)
    // formaer rtc_init_entry()
    virtual RTC::ReturnCode_t onInitialize();

    // The execution action that is invoked periodically
    // former rtc_active_do()
    virtual RTC::ReturnCode_t onExecute(RTC::UniqueId ec_id);

private:
    TimedOctetSeq m_in_data;
    InPort<TimedOctetSeq, MyRingBuffer> m_InPort;

    //TimedOctetSeq m_out_data;
    //OutPort<TimedOctetSeq, MyRingBuffer> m_OutPort;

private:
    int daq_dummy();
    int daq_configure();
    int daq_unconfigure();
    int daq_start();
    int daq_run();
    int daq_stop();
    int daq_pause();
    int daq_resume();
    int reset_InPort();

    int parse_params(::NVList* list);

    int m_in_status;
    int m_out_status;
    int m_sampling_rate;
    bool m_debug;

    static const int EVENT_BYTE_SIZE = 4;
    ////////// ROOT Histogram //////////
    TCanvas *m_canvas;
    TH1F    *m_histo;
    
    ////////// Condition database //////////
    static const std::string CONDITION_FILE;
    monitorParam m_monitorParam;
};


extern "C"
{
  void EchoMonitorInit(RTC::Manager* manager);
};

#endif // ECHOMONITOR_H
